==> haskell-crypton-connection-0.3.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-connection
version:              0.3.2
visibility:           public
id:                   crypton-connection-0.3.2-Kxhp1AsWf99fCM5JJfmYr
key:                  crypton-connection-0.3.2-Kxhp1AsWf99fCM5JJfmYr
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  b6b96e3811b31942ed86fe7acfb69624
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-connection-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-connection-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.3.2-Kxhp1AsWf99fCM5JJfmYr
depends:
    base-4.16.4.0 basement-0.0.16-G4nkr58NDViGBBKWcytFlJ
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-x509-1.7.6-3jVr56DvxggKC8dzi7hjps
    crypton-x509-store-1.6.9-LJAbSla6YJgJFrIQhO3NWX
    crypton-x509-system-1.6.7-9kp8FodIwr58u9V3vqjN9D
    crypton-x509-validation-1.6.12-FML16ZSXtXu1mGpWqziDF2
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    network-3.1.4.0-GfG23cgXhomCxCQnvsPNoG
    socks-0.6.1-LZu4uWSxGIH4Z05i4tKaKj tls-1.8.0-9d6R2NJskhy3dBc6kkjCe3

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-connection-0.3.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-connection
version:              0.3.2
visibility:           public
id:                   crypton-connection-0.3.2-Ast5NXqnZIdHPHUTw7p3xN
key:                  crypton-connection-0.3.2-Ast5NXqnZIdHPHUTw7p3xN
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  e2db0fdf06591fa025719bf1313e366a
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-connection-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-connection-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.3.2-Ast5NXqnZIdHPHUTw7p3xN
depends:
    base-4.16.4.0 basement-0.0.16-G4nkr58NDViGBBKWcytFlJ
    bytestring-0.11.4.0 containers-0.6.5.1
    crypton-x509-1.7.6-Kxd5ozJflcyItODVP5K1kF
    crypton-x509-store-1.6.9-2TuahvNnDETHjKzNDronvp
    crypton-x509-system-1.6.7-4ro4jzMtlIfEMJqi8SaMwr
    crypton-x509-validation-1.6.12-5ir02qqEbozC7HVG40x18d
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    network-3.1.4.0-JL8MfxNaZmuAIivQBcxkBq
    socks-0.6.1-F97hX8BGwMa6B91t2XcpCU tls-1.8.0-33SvPTqEATs8WftP4GQ6hv

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
